<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="da">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="20"/>
        <location filename="../mainwindow.cpp" line="93"/>
        <location filename="../mainwindow.cpp" line="1807"/>
        <location filename="../mainwindow.cpp" line="1822"/>
        <source>MX Package Installer</source>
        <translation>MX Pakkeinstallationsprogram</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="57"/>
        <source>Popular Applications</source>
        <translation>Populære programmer</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="83"/>
        <location filename="../mainwindow.cpp" line="96"/>
        <source>Package</source>
        <translation>Pakke</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="88"/>
        <location filename="../mainwindow.cpp" line="96"/>
        <source>Info</source>
        <translation>Info</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="93"/>
        <location filename="../mainwindow.ui" line="250"/>
        <location filename="../mainwindow.ui" line="653"/>
        <location filename="../mainwindow.ui" line="975"/>
        <location filename="../mainwindow.cpp" line="96"/>
        <source>Description</source>
        <translation>Beskrivelse</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="113"/>
        <location filename="../mainwindow.ui" line="216"/>
        <location filename="../mainwindow.ui" line="619"/>
        <location filename="../mainwindow.ui" line="944"/>
        <location filename="../mainwindow.ui" line="1208"/>
        <source>search</source>
        <translation>søg</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="123"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;Manage popular packages&lt;/span&gt;&lt;/p&gt;&lt;p&gt;Greyed out items have already been installed.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;Håndter populære pakker&lt;/span&gt;&lt;/p&gt;&lt;p&gt;Grå punkter er allerede installeret.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="153"/>
        <source>Stable Repo</source>
        <translation>Stable-softwarekilde</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="174"/>
        <location filename="../mainwindow.ui" line="564"/>
        <location filename="../mainwindow.ui" line="889"/>
        <location filename="../mainwindow.ui" line="1156"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Filter packages according to their status.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Filtrer pakker efter deres status.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="177"/>
        <location filename="../mainwindow.ui" line="181"/>
        <location filename="../mainwindow.ui" line="567"/>
        <location filename="../mainwindow.ui" line="571"/>
        <location filename="../mainwindow.ui" line="892"/>
        <location filename="../mainwindow.ui" line="896"/>
        <location filename="../mainwindow.cpp" line="2198"/>
        <source>All packages</source>
        <translation>Alle pakker</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="186"/>
        <location filename="../mainwindow.ui" line="576"/>
        <location filename="../mainwindow.ui" line="901"/>
        <location filename="../mainwindow.cpp" line="2212"/>
        <source>Installed</source>
        <translation>Installeret</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="191"/>
        <location filename="../mainwindow.ui" line="581"/>
        <location filename="../mainwindow.ui" line="906"/>
        <location filename="../mainwindow.cpp" line="2210"/>
        <source>Upgradable</source>
        <translation>Kan opgraderes</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="196"/>
        <location filename="../mainwindow.ui" line="586"/>
        <location filename="../mainwindow.ui" line="911"/>
        <location filename="../mainwindow.ui" line="1188"/>
        <location filename="../mainwindow.cpp" line="2177"/>
        <location filename="../mainwindow.cpp" line="2214"/>
        <location filename="../mainwindow.cpp" line="2303"/>
        <source>Not installed</source>
        <translation>Ikke installeret</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="240"/>
        <location filename="../mainwindow.ui" line="643"/>
        <location filename="../mainwindow.ui" line="965"/>
        <source>Package Name</source>
        <translation>Pakkenavn</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="245"/>
        <location filename="../mainwindow.ui" line="648"/>
        <location filename="../mainwindow.ui" line="970"/>
        <location filename="../mainwindow.ui" line="1243"/>
        <source>Version</source>
        <translation>Version</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="277"/>
        <location filename="../mainwindow.ui" line="680"/>
        <location filename="../mainwindow.ui" line="1002"/>
        <source>Total packages:</source>
        <translation>Samlet pakker:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="307"/>
        <location filename="../mainwindow.ui" line="710"/>
        <location filename="../mainwindow.ui" line="1032"/>
        <source>Installed:</source>
        <translation>Installeret:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="337"/>
        <location filename="../mainwindow.ui" line="740"/>
        <location filename="../mainwindow.ui" line="1062"/>
        <source>Upgradable:</source>
        <translation>Kan opgraderes:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="351"/>
        <location filename="../mainwindow.ui" line="1313"/>
        <source>Upgrade All</source>
        <translation>Opgrader alle</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="378"/>
        <location filename="../mainwindow.ui" line="767"/>
        <location filename="../mainwindow.ui" line="1089"/>
        <source>Hide library and developer packages</source>
        <translation>Skjul biblioteks- og udviklerpakker</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="400"/>
        <location filename="../mainwindow.ui" line="789"/>
        <location filename="../mainwindow.ui" line="1111"/>
        <source>Refresh list</source>
        <translation>Genopfrisk liste</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="417"/>
        <location filename="../mainwindow.ui" line="594"/>
        <location filename="../mainwindow.ui" line="919"/>
        <location filename="../mainwindow.ui" line="1456"/>
        <source>Greyed out items have already been installed.</source>
        <translation>Grå punkter er allerede installeret.</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="473"/>
        <location filename="../mainwindow.ui" line="536"/>
        <location filename="../mainwindow.ui" line="856"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;= Upgradable package. Newer version available in selected repository.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;= Pakke som kan opgraderes. Nyere version tilgængelig i valgte softwarekilde.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="493"/>
        <source>MX Test Repo</source>
        <translation>MX test-softwarekilde</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="813"/>
        <source>Debian Backports</source>
        <translation>Debian-backports</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1135"/>
        <source>Flatpaks</source>
        <translation>Flatpaks</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1159"/>
        <location filename="../mainwindow.ui" line="1163"/>
        <location filename="../mainwindow.cpp" line="2158"/>
        <source>All apps</source>
        <translation>Alle programmer</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1168"/>
        <location filename="../mainwindow.cpp" line="2163"/>
        <source>All runtimes</source>
        <translation>Alle runtimes</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1173"/>
        <location filename="../mainwindow.cpp" line="2168"/>
        <source>All available</source>
        <translation>Alle tilgængelige</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1178"/>
        <location filename="../mainwindow.cpp" line="2156"/>
        <location filename="../mainwindow.cpp" line="2298"/>
        <source>Installed apps</source>
        <translation>Installerede programmer</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1183"/>
        <location filename="../mainwindow.cpp" line="2154"/>
        <source>Installed runtimes</source>
        <translation>Installerede runtimes</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1233"/>
        <source>Short Name</source>
        <translation>Kort navn</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1238"/>
        <source>Full Package Name</source>
        <translation>Fuldt pakkenavn</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1248"/>
        <source>Size</source>
        <translation>Størrelse</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1292"/>
        <source>Total items </source>
        <translation>Samlet størrelse</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1306"/>
        <source>Installed apps:</source>
        <translation>Installerede programmer:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1359"/>
        <source>Advanced</source>
        <translation>Avanceret</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1389"/>
        <source>Total installed size:</source>
        <translation>Samlet installeret størrelse:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1406"/>
        <location filename="../mainwindow.ui" line="1410"/>
        <source>For all users</source>
        <translation>For alle brugere</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1415"/>
        <source>For current user</source>
        <translation>For nuværende bruger</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1433"/>
        <source>Remote (repo):</source>
        <translation>Fjern (repo):</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1476"/>
        <location filename="../mainwindow.cpp" line="1988"/>
        <location filename="../mainwindow.cpp" line="2112"/>
        <source>Console Output</source>
        <translation>Konsoloutput</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1482"/>
        <source>Enter</source>
        <translation>Enter</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1493"/>
        <source>Respond here, or just press Enter</source>
        <translation>Svar her, eller tryk blot på Enter</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1537"/>
        <source>Uninstall</source>
        <translation>Afinstaller</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1544"/>
        <source>Alt+U</source>
        <translation>Alt+A</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1560"/>
        <source>About this application</source>
        <translation>Om programmet</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1563"/>
        <source>About...</source>
        <translation>Om...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1570"/>
        <source>Alt+B</source>
        <translation>Alt+O</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1618"/>
        <source>Display help </source>
        <translation>Vis hjælp</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1621"/>
        <source>Help</source>
        <translation>Hjælp</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1628"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1644"/>
        <location filename="../mainwindow.cpp" line="1891"/>
        <location filename="../mainwindow.cpp" line="2292"/>
        <location filename="../mainwindow.cpp" line="2295"/>
        <source>Install</source>
        <translation>Installer</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1651"/>
        <source>Alt+I</source>
        <translation>Alt+I</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1670"/>
        <source>Quit application</source>
        <translation>Afslut programmet</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1673"/>
        <source>Close</source>
        <translation>Luk</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1680"/>
        <source>Alt+C</source>
        <translation>Alt+L</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="147"/>
        <source>Uninstalling packages...</source>
        <translation>Afinstallerer pakker...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="153"/>
        <source>Running post-uninstall operations...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="170"/>
        <source>Refreshing sources...</source>
        <translation>Genopfrisker kilder...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="183"/>
        <location filename="../mainwindow.cpp" line="944"/>
        <location filename="../mainwindow.cpp" line="1061"/>
        <location filename="../mainwindow.cpp" line="1177"/>
        <location filename="../mainwindow.cpp" line="1771"/>
        <location filename="../mainwindow.cpp" line="1786"/>
        <location filename="../mainwindow.cpp" line="1796"/>
        <location filename="../mainwindow.cpp" line="1959"/>
        <location filename="../mainwindow.cpp" line="1979"/>
        <location filename="../mainwindow.cpp" line="2382"/>
        <location filename="../mainwindow.cpp" line="2457"/>
        <location filename="../mainwindow.cpp" line="2484"/>
        <source>Error</source>
        <translation>Fejl</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="183"/>
        <source>There was a problem updating sources. Some sources may not have provided updates. For more info check: </source>
        <translation>Der var et problem med at opdatere kilder. Nogle kilder har måske ikke leveret opdateringer. For mere info, tjek: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="544"/>
        <location filename="../mainwindow.cpp" line="1813"/>
        <source>Cancel</source>
        <translation>Annuller</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="550"/>
        <source>Please wait...</source>
        <translation>Vent venligst...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="751"/>
        <location filename="../mainwindow.cpp" line="769"/>
        <source>Version </source>
        <translation>Version </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="751"/>
        <source> in stable repo</source>
        <translation> i stable-softwarekilde</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="753"/>
        <source>Not available in stable repo</source>
        <translation>Ikke tilgængelig i stable-softwarekilde</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="763"/>
        <location filename="../mainwindow.cpp" line="2093"/>
        <source>Latest version </source>
        <translation>Seneste version</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="763"/>
        <location filename="../mainwindow.cpp" line="2093"/>
        <source> already installed</source>
        <translation>allerede installeret</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="769"/>
        <source> installed</source>
        <translation>installeret</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="879"/>
        <source>You are about to use the MX Test repository, whose packages are provided for testing purposes only. It is possible that they might break your system, so it is suggested that you back up your system and install or update only one package at a time. Please provide feedback in the Forum so the package can be evaluated before moving up to Main.</source>
        <translation>Du er ved at bruge MX test-softwarekilden, med pakker som kun leveres til testformål. Der er mulighed for at de kan gøre dit system ubrugeligt, så det foreslås at du sikkerhedskopierer dit system og kun installerer én pakke af gangen. Giv venligst feedback i forummet så pakken kan evalueres inden den flyttes til Main.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="888"/>
        <source>You are about to use Debian Backports, which contains packages taken from the next Debian release (called &apos;testing&apos;), adjusted and recompiled for usage on Debian stable. They cannot be tested as extensively as in the stable releases of Debian and MX Linux, and are provided on an as-is basis, with risk of incompatibilities with other components in Debian stable. Use with care!</source>
        <translation>Du er ved at bruge Debian backports, som indeholder pakker som er taget fra den næste Debian-udgivelse (kaldet &apos;testing&apos;), justeret og genkompileret til brug i Debian stable. De kan ikke testes så omfattende som i de stabile udgivelser af Debian og MX Linux, og leveres på et som-de-er grundlag, med risiko for inkompatibilitet med andre komponenter i Debian stable. Brug med forsigtighed!</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="896"/>
        <source>MX Linux includes this repository of flatpaks for the users&apos; convenience only, and is not responsible for the functionality of the individual flatpaks themselves. For more, consult flatpaks in the Wiki.</source>
        <translation>MX Linux inkluderer kun denne softwarekilde af flatpaks for at gøre det let for brugerne, og er ikke ansvarlig for funktionaliteten af de enkelte flatpaks. Konsulter flatpaks i wikien for mere.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="905"/>
        <source>Warning</source>
        <translation>Advarsel</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="909"/>
        <source>Do not show this message again</source>
        <translation>Vis ikke meddelelsen igen</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="944"/>
        <location filename="../mainwindow.cpp" line="1061"/>
        <location filename="../mainwindow.cpp" line="1177"/>
        <source>Internet is not available, won&apos;t be able to download the list of packages</source>
        <translation>Internettet er ikke tilgængeligt, vil ikke være i stand til at downloade listen over pakkerne</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="949"/>
        <source>Installing packages...</source>
        <translation>Installerer pakker...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="989"/>
        <source>Post-processing...</source>
        <translation>Efterbehandling...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1021"/>
        <source>Pre-processing for </source>
        <translation>Præbehandling til </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1035"/>
        <source>Installing </source>
        <translation>Installerer</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1043"/>
        <source>Post-processing for </source>
        <translation>Efterbehandling til </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1187"/>
        <source>Downloading package info...</source>
        <translation>Downloader pakkeinfo...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1612"/>
        <source>Packages to be installed: </source>
        <translation>Pakker som skal installeres: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1649"/>
        <source>Package info</source>
        <translation>Pakkeinfo</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1767"/>
        <location filename="../mainwindow.cpp" line="1780"/>
        <location filename="../mainwindow.cpp" line="1793"/>
        <location filename="../mainwindow.cpp" line="1954"/>
        <location filename="../mainwindow.cpp" line="2378"/>
        <location filename="../mainwindow.cpp" line="2451"/>
        <location filename="../mainwindow.cpp" line="2478"/>
        <source>Done</source>
        <translation>Færdig</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1767"/>
        <location filename="../mainwindow.cpp" line="1780"/>
        <location filename="../mainwindow.cpp" line="1793"/>
        <location filename="../mainwindow.cpp" line="1954"/>
        <location filename="../mainwindow.cpp" line="1972"/>
        <location filename="../mainwindow.cpp" line="2378"/>
        <location filename="../mainwindow.cpp" line="2451"/>
        <location filename="../mainwindow.cpp" line="2478"/>
        <source>Processing finished successfully.</source>
        <translation>Behandlingen blev færdig.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1771"/>
        <location filename="../mainwindow.cpp" line="1786"/>
        <location filename="../mainwindow.cpp" line="1796"/>
        <location filename="../mainwindow.cpp" line="2382"/>
        <location filename="../mainwindow.cpp" line="2457"/>
        <location filename="../mainwindow.cpp" line="2484"/>
        <source>Problem detected while installing, please inspect the console output.</source>
        <translation>Problem registreret under installation, inspicer venligst outputtet fra konsolen.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1806"/>
        <source>About MX Package Installer</source>
        <translation>Om MX Pakkeinstallationsprogram</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1807"/>
        <source>Version: </source>
        <translation>Version: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1808"/>
        <source>Package Installer for MX Linux</source>
        <translation>Pakkeinstallationsprogram til MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1810"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Ophavsret (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1811"/>
        <location filename="../mainwindow.cpp" line="1822"/>
        <source>License</source>
        <translation>Licens</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1812"/>
        <source>Changelog</source>
        <translation>Ændringslog</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1834"/>
        <source>&amp;Close</source>
        <translation>&amp;Luk</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1889"/>
        <source>Reinstall</source>
        <translation>Geninstaller</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1959"/>
        <source>We encountered a problem uninstalling, please check output</source>
        <translation>Vi stødte på et problem under afinstallation, tjek venligst outputtet</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1972"/>
        <source>Success</source>
        <translation>Det lykkedes</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1979"/>
        <source>We encountered a problem uninstalling the program</source>
        <translation>Vi stødte på et problem ved afinstallation af programmet</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2069"/>
        <location filename="../mainwindow.cpp" line="2080"/>
        <source>Flatpak not installed</source>
        <translation>Flatpak ikke installeret</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2069"/>
        <source>Flatpak is not currently installed.
OK to go ahead and install it?</source>
        <translation>Flatpak er ikke installeret.
Er det OK at fortsætte og installere den?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2080"/>
        <source>Flatpak was not installed</source>
        <translation>Flatpak blev ikke installeret</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2100"/>
        <location filename="../mainwindow.cpp" line="2118"/>
        <source>Flathub remote failed</source>
        <translation>Flathub-fjern mislykkedes</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2100"/>
        <location filename="../mainwindow.cpp" line="2118"/>
        <source>Flathub remote could not be added</source>
        <translation>Flathub-fjern kunne ikke tilføjes</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2108"/>
        <source>Needs re-login</source>
        <translation>Behøver genindlodning</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2108"/>
        <source>You might need to logout/login to see installed items in the menu</source>
        <translation>Der kan være du skal logge ud og ind og se de installerede punkter i menuen</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2290"/>
        <source>Upgrade</source>
        <translation>Opgrader</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2409"/>
        <source>Quit?</source>
        <translation>Afslut?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2410"/>
        <source>Process still running, quitting might leave the system in an unstable state.&lt;p&gt;&lt;b&gt;Are you sure you want to exit MX Package Installer?&lt;/b&gt;</source>
        <translation>Processen kører stadig, afslutning kan efterlade systemet i en ustabil tilstand.&lt;p&gt;&lt;b&gt;Er du sikker på, at du vil afslutte MX Pakkeinstallationsprogrammet?&lt;/b&gt;</translation>
    </message>
</context>
<context>
    <name>ManageRemotes</name>
    <message>
        <location filename="../remotes.cpp" line="14"/>
        <source>Manage Flatpak Remotes</source>
        <translation>Håndter Flatpak-fjern</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="23"/>
        <source>For all users</source>
        <translation>For alle brugere</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="24"/>
        <source>For current user</source>
        <translation>For nuværende bruger</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="30"/>
        <source>enter Flatpak remote URL</source>
        <translation>Indtast URL for Flatpak-fjern</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="33"/>
        <source>enter Flatpakref location to install app</source>
        <translation>indtast Flatpakref-placering for at installere program</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="35"/>
        <source>Add or remove flatpak remotes (repos), or install apps using flatpakref URL or path</source>
        <translation>Tilføj eller fjern flatpak-fjerne (softwarekilder) eller installer programmer med flatpakref-URL eller -sti</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="44"/>
        <source>Remove remote</source>
        <translation>Fjern fjern</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="49"/>
        <source>Add remote</source>
        <translation>Tilføj fjern</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="54"/>
        <source>Install app</source>
        <translation>Installer program</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="59"/>
        <source>Close</source>
        <translation>Luk</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="81"/>
        <source>Not removable</source>
        <translation>Ikke flytbar</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="81"/>
        <source>Flathub is the main Flatpak remote and won&apos;t be removed</source>
        <translation>Flathub er den primære Flatpak-fjern og tilføjes ikke</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="97"/>
        <source>Error adding remote</source>
        <translation>Fejl ved tilføjelse af fjern</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="97"/>
        <source>Could not add remote - command returned an error. Please double-check the remote address and try again</source>
        <translation>Kunne ikke tilføje fjern - kommandoen returnerede en fejl. Dobbelttjek venligt fjernadressen og prøv igen</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="101"/>
        <source>Success</source>
        <translation>Det lykkedes</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="101"/>
        <source>Remote added successfully</source>
        <translation>Fjern blev tilføjet</translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <location filename="../main.cpp" line="58"/>
        <source>Unable to get exclusive lock</source>
        <translation>Kan ikke få eksklusiv lås</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="59"/>
        <source>Another package management application (like Synaptic or apt-get), is already running. Please close that application first</source>
        <translation>Der kører allerede et andet pakkehåndteringsprogram (såsom Synaptic eller apt-get). Luk venligst programmet først</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="77"/>
        <source>You must run this program as root.</source>
        <translation>Du skal køre programmet som root.</translation>
    </message>
</context>
</TS>
